@@ -17,14 +17,12 @@ def call(method, url, **kwargs):
 
     if "headers" not in kwargs:
         kwargs["headers"] = {}
-    kwargs['headers']['User-Agent'] = 'fordpass-na/353 CFNetwork/1121.2.2 Darwin/19.3.0'
+    kwargs['headers']['User-Agent'] = 'FordPass/5 CFNetwork/1327.0.4 Darwin/21.2.0'
 
     try:
         response = requests.request(method, url, timeout=310, **kwargs)
         code = response.status_code
 
-        print(response.json())
-
         if response.ok:
             return response
         elif code == 400:
