@@ -36,17 +36,20 @@ class User(object):
         return response.json()
 
     def vehicles(self):
-        """ GET User.vehicles
+        """ POST User.vehicles
 
         Returns:
             Response: User vehicle list
 
         """
 
-        response = self.api.get(
-            const.VEHICLE_URL,
-            'dashboard/v1/users/vehicles?country=USA&language=EN&region=US&skipRecall=true')
-        return response.json()
+        data = '{"dashboardRefreshRequest": "All", "smsWakeUpVIN": ""}'
+        response = self.api.post(
+            const.USER_URL,
+            'expdashboard/v1/details', data)
+
+        print(response)
+        return response.json()['userVehicles']['vehicleDetails']
 
     def add_vehicle(self, vehicle_id):
         """ POST User.add_vehicle
